@@ -6,7 +6,12 @@
 /* To avoid accidental use of non reentrant GEOS API. */
 #define GEOS_USE_ONLY_R_API
 
+// wrap geos.h import to silence geos gcc warnings
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wstrict-prototypes"
 #include <geos_c.h>
+#pragma GCC diagnostic pop
+
 
 #define RAISE_ILLEGAL_GEOS if (!PyErr_Occurred()) {PyErr_Format(PyExc_RuntimeError, "Uncaught GEOS exception");}
 #define GEOS_SINCE_350 ((GEOS_VERSION_MAJOR >= 3) && (GEOS_VERSION_MINOR >= 5))
